# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog][keepachangelog] and this project
adheres to [Semantic Versioning][semver].

## [Unreleased]

## [0.9.0] - 2017-09-17
### Added
- Started keeping a changelog

### Changed
- Major test suite overhaul
- Code cleanup


[semver]: http://semver.org/spec/v2.0.0.html
[keepachangelog]: http://keepachangelog.com/en/1.0.0/
